@@ -322,8 +322,8 @@ class BpmnValidator():
             if issues[0:5] == 'ERROR':
                 print(issues)
 
-            issues += str(transform(XSLT_VALIDATOR, bpmn_file))
-            issues += str(transform(XSLT_EXT_VALIDATOR, bpmn_file))
+            issues += str(transform(XSLT_VALIDATOR, bpmn_file, self.options))
+            issues += str(transform(XSLT_EXT_VALIDATOR, bpmn_file, self.options))
 
             issueArr = issues.split('\n')
             errs = list(filter(lambda issue: issue[0:5] == 'ERROR', issueArr))
@@ -609,7 +609,7 @@ class BpmDeployer():
 
     def generate_app(self, root):
         appPath = '%s/%s.app' % (root, root)
-        if exists(appPath) and not(args.force):
+        if exists(appPath) and not(self.options.force):
             if self.options.verbose:
                 print("  ... app '%s' already exists, --force to overwrite" % appPath)
         else:
@@ -648,7 +648,7 @@ class BpmDeployer():
             if self.options.verbose:
                 print("  ... found %s '%s', but it has no formKey"
                     % (local_tag(bpmn_obj), name))
-        elif exists(formPath) and not(args.force):
+        elif exists(formPath) and not(self.options.force):
             if self.options.verbose:
                 print("  ... found %s '%s', but form already exists with key '%s' --force to overwrite"
                     % (local_tag(bpmn_obj), name, formKey))
@@ -823,8 +823,8 @@ class Curl():
             if self.options.verbose:
                 print('ERROR: {}: {}'.format(e.code, e.reason))
 
-def cache(args):
-    if args.verbose:
+def cache(options):
+    if options.verbose:
         print('caching external resources...')
 
     if not(exists(CACHE_DIR)):
@@ -832,18 +832,18 @@ def cache(args):
         if not(exists(CACHE_DIR + '/xsd')):
             mkdir(CACHE_DIR + '/xsd', 0o755)
 
-    cache_file(XSD_BPMN, CACHE_DIR + '/xsd/BPMN20.xsd')
-    cache_file(XSD_BPMNDI, CACHE_DIR + '/xsd/BPMNDI.xsd')
-    cache_file(XSD_DC, CACHE_DIR + '/xsd/DC.xsd')
-    cache_file(XSD_DI, CACHE_DIR + '/xsd/DI.xsd')
-    cache_file(XSD_SEMANTIC, CACHE_DIR + '/xsd/Semantic.xsd')
+    cache_file(XSD_BPMN, CACHE_DIR + '/xsd/BPMN20.xsd', options)
+    cache_file(XSD_BPMNDI, CACHE_DIR + '/xsd/BPMNDI.xsd', options)
+    cache_file(XSD_DC, CACHE_DIR + '/xsd/DC.xsd', options)
+    cache_file(XSD_DI, CACHE_DIR + '/xsd/DI.xsd', options)
+    cache_file(XSD_SEMANTIC, CACHE_DIR + '/xsd/Semantic.xsd', options)
 
-    if args.verbose:
-      print('... done.')
+    if options.verbose:
+        print('... done.')
 
-def cache_file(url, file_path):
+def cache_file(url, file_path, options):
     if not(exists(file_path)):
-        if args.verbose:
+        if options.verbose:
             print('...%s...' % (file_path))
 
         file = open(file_path, 'wb')
@@ -860,7 +860,7 @@ def help(parser):
     print('{} {}'.format(__name__, kpctl.__version__))
     parser.print_help()
 
-def transform(xsl_file, xml_file):
+def transform(xsl_file, xml_file, options):
     dom = ET.parse(xml_file)
     res = requests.get(xsl_file)
     xslt = ET.fromstring(res.content)
@@ -868,7 +868,7 @@ def transform(xsl_file, xml_file):
       transform = ET.XSLT(xslt)
     except Exception as e:
       print(e)
-    if args.debug:
+    if options.debug:
       return transform(dom, verbosity="0")
     else:
       # collect all (v=1) and let decide calling func decide what to report
@@ -996,5 +996,7 @@ def main():
         sys.exit(e.err.value)
 
 # Do it!
-kpctl.main()
+if __name__ == "kpctl":
+    from kpctl import kpctl
+    kpctl.main()
 
